# `{self.name}`
![Replace with your own inspirational logo here](https://github.com/PFython/easypypi/blob/main/easypypi.png?raw=true)

# 1. OVERVIEW
{self.description}

# 2. INSTALLATION

    pip install {self.name}


# 3. BASIC USE

    >>> import {self.name}


# 4. UNDER THE BONNET

# 5. CONTRIBUTING

Contact {self.author} {self.email} or feel free to raise Pull Requests / Issue in the normal Github way.

# 6. CREDITS

# 7. PAYING IT FORWARD


If `{self.name}` helps you save time and focus on more important things, please feel free to to show your appreciation by starring the repository on Github.

I'd also be delighted if you wanted to:

<a href="https://www.buymeacoffee.com/{self.Github_username}" target="_blank"><img src="https://cdn.buymeacoffee.com/buttons/v2/arial-yellow.png" alt="Buy Me A Coffee" width="217px" ></a>
